@@ -5,7 +5,7 @@ import jinja2
 import readline
 from os.path import join
 from pythong.util import (ask_yes_no, prompt_input, determine_directories,
-                         write_config, read_config)
+                          write_config, read_config)
 from pythong.classifiers import CLASSIFIERS
 
 jinja_env = jinja2.Environment(
@@ -76,7 +76,8 @@ def prompt_new_project(name=None, snap=False):
         license="",
         requires=[]))
 
-    if not snap and ask_yes_no("Would you like help creating a setup.py file?"):
+    if not snap and ask_yes_no("Would you like help creating a setup.py "
+                               "file?"):
         project.update(dict(
             encoding=prompt_input("Encoding [utf8]: ", default='utf8'),
             version=prompt_input("Version [0.1.0]: ", default='0.1.0'),
@@ -85,13 +86,16 @@ def prompt_new_project(name=None, snap=False):
             description=prompt_input("Description [A new project]: ",
                                      default='A new project'),
             classifiers=prompt_classifiers(),
-            keywords=prompt_input("Keywords (comma delimited): ").split(','),
+            keywords=[x.strip() for x in
+                      prompt_input("Keywords (comma delimited): ",
+                                   default="").split(',')],
             author=prompt_input("Author: "),
             email=prompt_input("Author email: "),
             url=prompt_input("Project URL: "),
             license=prompt_input("License: "),
-            requires=prompt_input("Requirements (comma delimited): "
-                                  ).split(',')))
+            requires=[x.strip() for x in
+                      prompt_input("Requirements (comma delimited): ",
+                                   default="").split(',')]))
     else:
         print "Generating skeletal setup files."
 
@@ -120,7 +124,8 @@ def write_setup_files(project_dir):
 def prompt_classifiers(applicable=None):
     """
     Prompt the user to pick classifiers that apply to their project.
-    Optionally takes a list of preselected classifiers (maybe for license later)
+    Optionally takes a list of preselected classifiers
+    (maybe for license later)
     """
     if applicable is None:
         applicable = []
@@ -130,6 +135,8 @@ def prompt_classifiers(applicable=None):
     while True:
         selection = recurse_prompt(CLASSIFIERS)
         if selection is None:
+            continue
+        if selection is False:
             return applicable
         applicable.append(selection)
         if len(applicable) > 0:
@@ -144,16 +151,17 @@ def recurse_prompt(tree, sofar=""):
         #get rid of the trailing " :: "
         return sofar[:-4]
 
-    if not any(tree.values()):
-        return sofar + prompt_optionlist(sorted(tree.keys()))
-
     selection = prompt_optionlist(sorted(tree.keys()))
 
     if selection is None:
+        if sofar == "":
+            return False
         return None
     sofar += selection + " :: "
-    selection = recurse_prompt(tree[selection], sofar)
-    return selection
+    if not any(tree.values()):
+        # get rid of trailing " :: "
+        return sofar[:-4]
+    return recurse_prompt(tree[selection], sofar)
 
 
 def prompt_optionlist(options):
